==> nextcloud-23.0.3.tgz: nextcloud/apps/user_status/l10n/hr.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Nedavni statusi",
    "In a meeting" : "Na sastanku",
    "Commuting" : "Na putu",
    "Out sick" : "Na bolovanju",
    "Vacationing" : "Na odmoru",
    "Working remotely" : "Rad na daljinu",
    "In a call" : "U pozivu",
    "User status" : "Status korisnika",
    "View profile" : "Prikaži profil",
    "Clear status message after" : "Izbriši poruku statusa nakon",
    "What is your status?" : "Koji je vaš status?",
    "Set status" : "Postavi status",
    "Online status" : "Status na mreži",
    "Status message" : "Poruka statusa",
    "Clear status message" : "Izbriši poruku statusa",
    "Set status message" : "Postavi poruku statusa",
    "There was an error saving the status" : "Došlo je do pogreške pri spremanju statusa",
    "There was an error clearing the status" : "Došlo je do pogreške pri brisanju statusa",
    "No recent status changes" : "Nema nedavnih promjena statusa",
    "Away" : "Odsutan",
    "Do not disturb" : "Ne ometaj",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Ne briši",
    "Today" : "Danas",
    "This week" : "Ovaj tjedan",
    "Online" : "Na mreži",
    "Invisible" : "Nevidljiva",
    "Offline" : "Izvanmrežno",
    "There was an error saving the new status" : "Došlo je do pogreške pri spremanju novog statusa",
    "30 minutes" : "30 minuta",
    "1 hour" : "1 sat",
    "4 hours" : "4 sata",
    "Mute all notifications" : "Utišaj sve obavijesti",
    "Appear offline" : "Prikaži izvanmrežno",
    "What's your status?" : "Koji je vaš status?"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-25.0.5.tgz: nextcloud/apps/user_status/l10n/hr.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Nedavni statusi",
    "In a meeting" : "Na sastanku",
    "Commuting" : "Na putu",
    "Out sick" : "Na bolovanju",
    "Vacationing" : "Na odmoru",
    "Working remotely" : "Rad na daljinu",
    "In a call" : "U pozivu",
    "User status" : "Status korisnika",
    "View profile" : "Prikaži profil",
    "Clear status after" : "Izbriši status nakon",
    "What is your status?" : "Koji je vaš status?",
    "Set status" : "Postavi status",
    "Online status" : "Status na mreži",
    "Status message" : "Poruka statusa",
    "Clear status message" : "Izbriši poruku statusa",
    "Set status message" : "Postavi poruku statusa",
    "There was an error saving the status" : "Došlo je do pogreške pri spremanju statusa",
    "There was an error clearing the status" : "Došlo je do pogreške pri brisanju statusa",
    "No recent status changes" : "Nema nedavnih promjena statusa",
    "Away" : "Odsutan",
    "Do not disturb" : "Ne ometaj",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Ne briši",
    "Today" : "Danas",
    "This week" : "Ovaj tjedan",
    "Online" : "Na mreži",
    "Invisible" : "Nevidljiva",
    "Offline" : "Izvanmrežno",
    "There was an error saving the new status" : "Došlo je do pogreške pri spremanju novog statusa",
    "30 minutes" : "30 minuta",
    "1 hour" : "1 sat",
    "4 hours" : "4 sata",
    "Mute all notifications" : "Utišaj sve obavijesti",
    "Appear offline" : "Prikaži izvanmrežno",
    "Clear status message after" : "Izbriši poruku statusa nakon"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
